package main

import (
	"encoding/hex"
)

const HashLen = 32

type Hash [HashLen]byte

var HashNull Hash

func (h Hash) String() string {
	return hex.EncodeToString(h[:])
}
